# Generated by Django 4.2 on 2026-01-27 12:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('brevo_analytics', '0004_alter_brevoemail_options_brevoemail_blacklist_info'),
    ]

    operations = [
        migrations.AddField(
            model_name='brevoemail',
            name='sender_email',
            field=models.EmailField(blank=True, db_index=True, help_text='Sender email address (for multi-tenant filtering)', max_length=254, null=True),
        ),
    ]
